.. _libdoc_tensor:

==================================================
:mod:`tensor`  -- Types and Ops for Symbolic numpy
==================================================

.. module:: tensor
   :platform: Unix, Windows
   :synopsis: symbolic types and operations for n-dimensional arrays.
.. moduleauthor:: LISA

Theano's strength is in expressing symbolic calculations involving tensors.
There are many types of symbolic expressions for tensors.
They are grouped into the following sections:


.. toctree::
    :maxdepth: 1

    basic
    random/index
    utils
    elemwise
    extra_ops
    io
    slinalg
    nlinalg
    fft
    math_opt
    basic_opt
